"Main interface for codestar-notifications service"

from mypy_boto3_codestar_notifications.client import Client
from mypy_boto3_codestar_notifications.paginator import (
    ListEventTypesPaginator,
    ListNotificationRulesPaginator,
    ListTargetsPaginator,
)


__all__ = (
    "Client",
    "ListEventTypesPaginator",
    "ListNotificationRulesPaginator",
    "ListTargetsPaginator",
)



"Main interface for codestar-notifications service Client"
from __future__ import annotations

import sys
from typing import Any, Dict, List, overload
from botocore.client import BaseClient
from botocore.exceptions import ClientError as Boto3ClientError

# pylint: disable=import-self
import mypy_boto3_codestar_notifications.client as client_scope

# pylint: disable=import-self
import mypy_boto3_codestar_notifications.paginator as paginator_scope
from mypy_boto3_codestar_notifications.type_defs import (
    ClientCreateNotificationRuleResponseTypeDef,
    ClientCreateNotificationRuleTargetsTypeDef,
    ClientDeleteNotificationRuleResponseTypeDef,
    ClientDescribeNotificationRuleResponseTypeDef,
    ClientListEventTypesFiltersTypeDef,
    ClientListEventTypesResponseTypeDef,
    ClientListNotificationRulesFiltersTypeDef,
    ClientListNotificationRulesResponseTypeDef,
    ClientListTagsForResourceResponseTypeDef,
    ClientListTargetsFiltersTypeDef,
    ClientListTargetsResponseTypeDef,
    ClientSubscribeResponseTypeDef,
    ClientSubscribeTargetTypeDef,
    ClientTagResourceResponseTypeDef,
    ClientUnsubscribeResponseTypeDef,
    ClientUpdateNotificationRuleTargetsTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("Client",)


class Client(BaseClient):
    """
    [CodeStarNotifications.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client)
    """

    exceptions: client_scope.Exceptions

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.can_paginate)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def create_notification_rule(
        self,
        Name: str,
        EventTypeIds: List[str],
        Resource: str,
        Targets: List[ClientCreateNotificationRuleTargetsTypeDef],
        DetailType: Literal["BASIC", "FULL"],
        ClientRequestToken: str = None,
        Tags: Dict[str, str] = None,
        Status: Literal["ENABLED", "DISABLED"] = None,
    ) -> ClientCreateNotificationRuleResponseTypeDef:
        """
        [Client.create_notification_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_notification_rule(self, Arn: str) -> ClientDeleteNotificationRuleResponseTypeDef:
        """
        [Client.delete_notification_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_notification_rule)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def delete_target(self, TargetAddress: str, ForceUnsubscribeAll: bool = None) -> Dict[str, Any]:
        """
        [Client.delete_target documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_target)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def describe_notification_rule(self, Arn: str) -> ClientDescribeNotificationRuleResponseTypeDef:
        """
        [Client.describe_notification_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.describe_notification_rule)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> None:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.generate_presigned_url)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_event_types(
        self,
        Filters: List[ClientListEventTypesFiltersTypeDef] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListEventTypesResponseTypeDef:
        """
        [Client.list_event_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_event_types)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_notification_rules(
        self,
        Filters: List[ClientListNotificationRulesFiltersTypeDef] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListNotificationRulesResponseTypeDef:
        """
        [Client.list_notification_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_tags_for_resource(self, Arn: str) -> ClientListTagsForResourceResponseTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_tags_for_resource)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def list_targets(
        self,
        Filters: List[ClientListTargetsFiltersTypeDef] = None,
        NextToken: str = None,
        MaxResults: int = None,
    ) -> ClientListTargetsResponseTypeDef:
        """
        [Client.list_targets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def subscribe(
        self, Arn: str, Target: ClientSubscribeTargetTypeDef, ClientRequestToken: str = None
    ) -> ClientSubscribeResponseTypeDef:
        """
        [Client.subscribe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def tag_resource(self, Arn: str, Tags: Dict[str, str]) -> ClientTagResourceResponseTypeDef:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.tag_resource)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def unsubscribe(self, Arn: str, TargetAddress: str) -> ClientUnsubscribeResponseTypeDef:
        """
        [Client.unsubscribe documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def untag_resource(self, Arn: str, TagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.untag_resource)
        """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def update_notification_rule(
        self,
        Arn: str,
        Name: str = None,
        Status: Literal["ENABLED", "DISABLED"] = None,
        EventTypeIds: List[str] = None,
        Targets: List[ClientUpdateNotificationRuleTargetsTypeDef] = None,
        DetailType: Literal["BASIC", "FULL"] = None,
    ) -> Dict[str, Any]:
        """
        [Client.update_notification_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_event_types"]
    ) -> paginator_scope.ListEventTypesPaginator:
        """
        [Paginator.ListEventTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_notification_rules"]
    ) -> paginator_scope.ListNotificationRulesPaginator:
        """
        [Paginator.ListNotificationRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
        """

    @overload
    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def get_paginator(
        self, operation_name: Literal["list_targets"]
    ) -> paginator_scope.ListTargetsPaginator:
        """
        [Paginator.ListTargets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
        """


class Exceptions:
    AccessDeniedException: Boto3ClientError
    ClientError: Boto3ClientError
    ConcurrentModificationException: Boto3ClientError
    ConfigurationException: Boto3ClientError
    InvalidNextTokenException: Boto3ClientError
    LimitExceededException: Boto3ClientError
    ResourceAlreadyExistsException: Boto3ClientError
    ResourceNotFoundException: Boto3ClientError
    ValidationException: Boto3ClientError



"Main interface for codestar-notifications service type defs"
from __future__ import annotations

from datetime import datetime
import sys
from typing import Dict, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


ClientCreateNotificationRuleResponseTypeDef = TypedDict(
    "ClientCreateNotificationRuleResponseTypeDef", {"Arn": str}, total=False
)

ClientCreateNotificationRuleTargetsTypeDef = TypedDict(
    "ClientCreateNotificationRuleTargetsTypeDef",
    {"TargetType": str, "TargetAddress": str},
    total=False,
)

ClientDeleteNotificationRuleResponseTypeDef = TypedDict(
    "ClientDeleteNotificationRuleResponseTypeDef", {"Arn": str}, total=False
)

ClientDescribeNotificationRuleResponseEventTypesTypeDef = TypedDict(
    "ClientDescribeNotificationRuleResponseEventTypesTypeDef",
    {"EventTypeId": str, "ServiceName": str, "EventTypeName": str, "ResourceType": str},
    total=False,
)

ClientDescribeNotificationRuleResponseTargetsTypeDef = TypedDict(
    "ClientDescribeNotificationRuleResponseTargetsTypeDef",
    {
        "TargetAddress": str,
        "TargetType": str,
        "TargetStatus": Literal["PENDING", "ACTIVE", "UNREACHABLE", "INACTIVE", "DEACTIVATED"],
    },
    total=False,
)

ClientDescribeNotificationRuleResponseTypeDef = TypedDict(
    "ClientDescribeNotificationRuleResponseTypeDef",
    {
        "Arn": str,
        "Name": str,
        "EventTypes": List[ClientDescribeNotificationRuleResponseEventTypesTypeDef],
        "Resource": str,
        "Targets": List[ClientDescribeNotificationRuleResponseTargetsTypeDef],
        "DetailType": Literal["BASIC", "FULL"],
        "CreatedBy": str,
        "Status": Literal["ENABLED", "DISABLED"],
        "CreatedTimestamp": datetime,
        "LastModifiedTimestamp": datetime,
        "Tags": Dict[str, str],
    },
    total=False,
)

_RequiredClientListEventTypesFiltersTypeDef = TypedDict(
    "_RequiredClientListEventTypesFiltersTypeDef",
    {"Name": Literal["RESOURCE_TYPE", "SERVICE_NAME"]},
)
_OptionalClientListEventTypesFiltersTypeDef = TypedDict(
    "_OptionalClientListEventTypesFiltersTypeDef", {"Value": str}, total=False
)


class ClientListEventTypesFiltersTypeDef(
    _RequiredClientListEventTypesFiltersTypeDef, _OptionalClientListEventTypesFiltersTypeDef
):
    pass


ClientListEventTypesResponseEventTypesTypeDef = TypedDict(
    "ClientListEventTypesResponseEventTypesTypeDef",
    {"EventTypeId": str, "ServiceName": str, "EventTypeName": str, "ResourceType": str},
    total=False,
)

ClientListEventTypesResponseTypeDef = TypedDict(
    "ClientListEventTypesResponseTypeDef",
    {"EventTypes": List[ClientListEventTypesResponseEventTypesTypeDef], "NextToken": str},
    total=False,
)

ClientListNotificationRulesFiltersTypeDef = TypedDict(
    "ClientListNotificationRulesFiltersTypeDef",
    {"Name": Literal["EVENT_TYPE_ID", "CREATED_BY", "RESOURCE", "TARGET_ADDRESS"], "Value": str},
    total=False,
)

ClientListNotificationRulesResponseNotificationRulesTypeDef = TypedDict(
    "ClientListNotificationRulesResponseNotificationRulesTypeDef",
    {"Id": str, "Arn": str},
    total=False,
)

ClientListNotificationRulesResponseTypeDef = TypedDict(
    "ClientListNotificationRulesResponseTypeDef",
    {
        "NextToken": str,
        "NotificationRules": List[ClientListNotificationRulesResponseNotificationRulesTypeDef],
    },
    total=False,
)

ClientListTagsForResourceResponseTypeDef = TypedDict(
    "ClientListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
)

ClientListTargetsFiltersTypeDef = TypedDict(
    "ClientListTargetsFiltersTypeDef",
    {"Name": Literal["TARGET_TYPE", "TARGET_ADDRESS", "TARGET_STATUS"], "Value": str},
    total=False,
)

ClientListTargetsResponseTargetsTypeDef = TypedDict(
    "ClientListTargetsResponseTargetsTypeDef",
    {
        "TargetAddress": str,
        "TargetType": str,
        "TargetStatus": Literal["PENDING", "ACTIVE", "UNREACHABLE", "INACTIVE", "DEACTIVATED"],
    },
    total=False,
)

ClientListTargetsResponseTypeDef = TypedDict(
    "ClientListTargetsResponseTypeDef",
    {"Targets": List[ClientListTargetsResponseTargetsTypeDef], "NextToken": str},
    total=False,
)

ClientSubscribeResponseTypeDef = TypedDict(
    "ClientSubscribeResponseTypeDef", {"Arn": str}, total=False
)

ClientSubscribeTargetTypeDef = TypedDict(
    "ClientSubscribeTargetTypeDef", {"TargetType": str, "TargetAddress": str}, total=False
)

ClientTagResourceResponseTypeDef = TypedDict(
    "ClientTagResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
)

ClientUnsubscribeResponseTypeDef = TypedDict(
    "ClientUnsubscribeResponseTypeDef", {"Arn": str}, total=False
)

ClientUpdateNotificationRuleTargetsTypeDef = TypedDict(
    "ClientUpdateNotificationRuleTargetsTypeDef",
    {"TargetType": str, "TargetAddress": str},
    total=False,
)

_RequiredListEventTypesPaginateFiltersTypeDef = TypedDict(
    "_RequiredListEventTypesPaginateFiltersTypeDef",
    {"Name": Literal["RESOURCE_TYPE", "SERVICE_NAME"]},
)
_OptionalListEventTypesPaginateFiltersTypeDef = TypedDict(
    "_OptionalListEventTypesPaginateFiltersTypeDef", {"Value": str}, total=False
)


class ListEventTypesPaginateFiltersTypeDef(
    _RequiredListEventTypesPaginateFiltersTypeDef, _OptionalListEventTypesPaginateFiltersTypeDef
):
    pass


ListEventTypesPaginatePaginationConfigTypeDef = TypedDict(
    "ListEventTypesPaginatePaginationConfigTypeDef",
    {"MaxItems": int, "PageSize": int, "StartingToken": str},
    total=False,
)

ListEventTypesPaginateResponseEventTypesTypeDef = TypedDict(
    "ListEventTypesPaginateResponseEventTypesTypeDef",
    {"EventTypeId": str, "ServiceName": str, "EventTypeName": str, "ResourceType": str},
    total=False,
)

ListEventTypesPaginateResponseTypeDef = TypedDict(
    "ListEventTypesPaginateResponseTypeDef",
    {"EventTypes": List[ListEventTypesPaginateResponseEventTypesTypeDef]},
    total=False,
)

ListNotificationRulesPaginateFiltersTypeDef = TypedDict(
    "ListNotificationRulesPaginateFiltersTypeDef",
    {"Name": Literal["EVENT_TYPE_ID", "CREATED_BY", "RESOURCE", "TARGET_ADDRESS"], "Value": str},
    total=False,
)

ListNotificationRulesPaginatePaginationConfigTypeDef = TypedDict(
    "ListNotificationRulesPaginatePaginationConfigTypeDef",
    {"MaxItems": int, "PageSize": int, "StartingToken": str},
    total=False,
)

ListNotificationRulesPaginateResponseNotificationRulesTypeDef = TypedDict(
    "ListNotificationRulesPaginateResponseNotificationRulesTypeDef",
    {"Id": str, "Arn": str},
    total=False,
)

ListNotificationRulesPaginateResponseTypeDef = TypedDict(
    "ListNotificationRulesPaginateResponseTypeDef",
    {"NotificationRules": List[ListNotificationRulesPaginateResponseNotificationRulesTypeDef]},
    total=False,
)

ListTargetsPaginateFiltersTypeDef = TypedDict(
    "ListTargetsPaginateFiltersTypeDef",
    {"Name": Literal["TARGET_TYPE", "TARGET_ADDRESS", "TARGET_STATUS"], "Value": str},
    total=False,
)

ListTargetsPaginatePaginationConfigTypeDef = TypedDict(
    "ListTargetsPaginatePaginationConfigTypeDef",
    {"MaxItems": int, "PageSize": int, "StartingToken": str},
    total=False,
)

ListTargetsPaginateResponseTargetsTypeDef = TypedDict(
    "ListTargetsPaginateResponseTargetsTypeDef",
    {
        "TargetAddress": str,
        "TargetType": str,
        "TargetStatus": Literal["PENDING", "ACTIVE", "UNREACHABLE", "INACTIVE", "DEACTIVATED"],
    },
    total=False,
)

ListTargetsPaginateResponseTypeDef = TypedDict(
    "ListTargetsPaginateResponseTypeDef",
    {"Targets": List[ListTargetsPaginateResponseTargetsTypeDef]},
    total=False,
)



"Main interface for codestar-notifications service Paginators"
from __future__ import annotations

from typing import List
from botocore.paginate import Paginator as Boto3Paginator
from mypy_boto3_codestar_notifications.type_defs import (
    ListEventTypesPaginateFiltersTypeDef,
    ListEventTypesPaginatePaginationConfigTypeDef,
    ListEventTypesPaginateResponseTypeDef,
    ListNotificationRulesPaginateFiltersTypeDef,
    ListNotificationRulesPaginatePaginationConfigTypeDef,
    ListNotificationRulesPaginateResponseTypeDef,
    ListTargetsPaginateFiltersTypeDef,
    ListTargetsPaginatePaginationConfigTypeDef,
    ListTargetsPaginateResponseTypeDef,
)


__all__ = ("ListEventTypesPaginator", "ListNotificationRulesPaginator", "ListTargetsPaginator")


class ListEventTypesPaginator(Boto3Paginator):
    """
    Paginator for `list_event_types`
    """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def paginate(
        self,
        Filters: List[ListEventTypesPaginateFiltersTypeDef] = None,
        PaginationConfig: ListEventTypesPaginatePaginationConfigTypeDef = None,
    ) -> ListEventTypesPaginateResponseTypeDef:
        """
        [ListEventTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes.paginate)
        """


class ListNotificationRulesPaginator(Boto3Paginator):
    """
    Paginator for `list_notification_rules`
    """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def paginate(
        self,
        Filters: List[ListNotificationRulesPaginateFiltersTypeDef] = None,
        PaginationConfig: ListNotificationRulesPaginatePaginationConfigTypeDef = None,
    ) -> ListNotificationRulesPaginateResponseTypeDef:
        """
        [ListNotificationRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules.paginate)
        """


class ListTargetsPaginator(Boto3Paginator):
    """
    Paginator for `list_targets`
    """

    # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
    def paginate(
        self,
        Filters: List[ListTargetsPaginateFiltersTypeDef] = None,
        PaginationConfig: ListTargetsPaginatePaginationConfigTypeDef = None,
    ) -> ListTargetsPaginateResponseTypeDef:
        """
        [ListTargets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.34/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets.paginate)
        """
